# FrImCla

FrImCla is an open-source framework for Image Classification using traditional and deep learning techniques. It supports a wide variety of deep learning and classical computer vision models.

## Features

Several feature extractors methods and machine learning algorithms are provided.
Jupyter notebooks to guide the use of the framework.
Different input modes for using the framework (Jupyter notebooks, configuration files, API).
The best model is trained automatically.
It is possible to easily add new feature extractor methods and machine learning algorithms and apply them for object classification.
